==> tuia-news-center-api-0.0.65_zwb27-20180911.074305-1-sources.jar: cn/com/duiba/tuia/news/center/dto/JumpConfigDto.java <==
package cn.com.duiba.tuia.news.center.dto;

/**
 * description: 跳转配置dto
 * <p>
 * author : zhangrui
 * date : 2018/9/10 20:37
 */
public class JumpConfigDto {


    /**
     * 主键
     */
    private Long id;
    /**
     * 用户类型 0：老用户  1：新用户
      */
    private Integer userType;

    /**
     * 配置项类型 1: 浮标  2:页面弹窗 3:活动 4：我的页面tab
     */
    private Integer categoryType;

    /**
     * 当category_type 为活动  category_item 对应 活动类型
     */
    private Integer categoryItem;
    /**
     * 页面跳转链接
     */
    private String routeUrl;

    /**
     * 跳转开始页面图片
     */
    private String routeImg;

    /**
     * 1:android 2:iOS
     */
    private Integer platform;

    /**
     * 起始版本号（包含）
     */
    private Long versionStart;

    /**
     * 截止版本号（不包含）
     */
    private Long versionEnd;

    /**
     * 是否启用组合策略  false：不启用 true：启用
     */
    private Boolean isAssemble;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Integer getUserType() {
        return userType;
    }

    public void setUserType(Integer userType) {
        this.userType = userType;
    }

    public Integer getCategoryType() {
        return categoryType;
    }

    public void setCategoryType(Integer categoryType) {
        this.categoryType = categoryType;
    }

    public Integer getCategoryItem() {
        return categoryItem;
    }

    public void setCategoryItem(Integer categoryItem) {
        this.categoryItem = categoryItem;
    }

    public String getRouteUrl() {
        return routeUrl;
    }

    public void setRouteUrl(String routeUrl) {
        this.routeUrl = routeUrl;
    }

    public String getRouteImg() {
        return routeImg;
    }

    public void setRouteImg(String routeImg) {
        this.routeImg = routeImg;
    }

    public Integer getPlatform() {
        return platform;
    }

    public void setPlatform(Integer platform) {
        this.platform = platform;
    }

    public Long getVersionStart() {
        return versionStart;
    }

    public void setVersionStart(Long versionStart) {
        this.versionStart = versionStart;
    }

    public Long getVersionEnd() {
        return versionEnd;
    }

    public void setVersionEnd(Long versionEnd) {
        this.versionEnd = versionEnd;
    }

    public Boolean getAssemble() {
        return isAssemble;
    }

    public void setAssemble(Boolean assemble) {
        isAssemble = assemble;
    }
}

==> tuia-news-center-api-1.9.4.3.zwb1-20190311.102530-2-sources.jar: cn/com/duiba/tuia/news/center/dto/JumpConfigDto.java <==
package cn.com.duiba.tuia.news.center.dto;

import java.io.Serializable;
import java.util.List;

/**
 * description: 跳转配置dto
 * <p>
 * author : zhangrui
 * date : 2018/9/10 20:37
 */
public class JumpConfigDto implements Serializable{


    /**
     * 主键
     */
    private Long id;
    /**
     * 用户类型 0：老用户  1：新用户
      */
    private Integer userType;

    /**
     * 配置项类型 1: 浮标  2:页面弹窗 3:活动 4：我的页面tab
     */
    private Integer categoryType;

    /**
     * 当category_type 为活动  category_item 对应 活动类型
     */
    private Integer categoryItem;
    /**
     * 页面跳转链接
     */
    private String routeUrl;

    /**
     * 跳转开始页面图片
     */
    private String routeImg;

    /**
     * 0:android 1:iOS
     */
    private Integer platform;

    /**
     * 起始版本号（包含）
     */
    private Long versionStart;

    /**
     * 截止版本号（不包含）
     */
    private Long versionEnd;

    /**
     * 是否启用组合策略  false：不启用 true：启用
     */
    private Boolean isAssemble;
    /**
     * 跳转链接列表
     */
    private List<RouteConfigDto> routeConfigDtoList;

    public List<RouteConfigDto> getRouteConfigDtoList() {
        return routeConfigDtoList;
    }

    public void setRouteConfigDtoList(List<RouteConfigDto> routeConfigDtoList) {
        this.routeConfigDtoList = routeConfigDtoList;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Integer getUserType() {
        return userType;
    }

    public void setUserType(Integer userType) {
        this.userType = userType;
    }

    public Integer getCategoryType() {
        return categoryType;
    }

    public void setCategoryType(Integer categoryType) {
        this.categoryType = categoryType;
    }

    public Integer getCategoryItem() {
        return categoryItem;
    }

    public void setCategoryItem(Integer categoryItem) {
        this.categoryItem = categoryItem;
    }

    public String getRouteUrl() {
        return routeUrl;
    }

    public void setRouteUrl(String routeUrl) {
        this.routeUrl = routeUrl;
    }

    public String getRouteImg() {
        return routeImg;
    }

    public void setRouteImg(String routeImg) {
        this.routeImg = routeImg;
    }

    public Integer getPlatform() {
        return platform;
    }

    public void setPlatform(Integer platform) {
        this.platform = platform;
    }

    public Long getVersionStart() {
        return versionStart;
    }

    public void setVersionStart(Long versionStart) {
        this.versionStart = versionStart;
    }

    public Long getVersionEnd() {
        return versionEnd;
    }

    public void setVersionEnd(Long versionEnd) {
        this.versionEnd = versionEnd;
    }

    public Boolean getAssemble() {
        return isAssemble;
    }

    public void setAssemble(Boolean assemble) {
        isAssemble = assemble;
    }
}
